package SQ.Blocks.Indicators.MA;

import com.strategyquant.lib.*;
import com.strategyquant.datalib.*;
import com.strategyquant.tradinglib.*;

import SQ.Internal.IndicatorBlock;

@BuildingBlock(name="(MA) Moving Average", display="MA(#Period#, #Method#)[#Shift#]", returnType = ReturnTypes.Price)
@IgnoreInBuilder
public class MA extends IndicatorBlock {

	@Parameter
	public DataSeries Input;

	@Parameter(defaultValue="14")
	public int Period;
	
	@Parameter(name="Method", defaultValue="0")
	@Editor(type=Editors.Selection, values="Simple=0,Exponential=1,Smoothed=2,Linear weighted=3")
	public int MAMethod;
	
	@Output(name = "MA", color = Colors.Red)
	public DataSeries Value;
	
	//------------------------------------------------------------------------
	//------------------------------------------------------------------------
	//------------------------------------------------------------------------
	
	@Override
	protected void OnBarUpdate() throws TradingException {
		double indiValue;
		
		switch(MAMethod){
			case 0: indiValue = Indicators.SMA(Input, Period).Value.get(0); break;
			case 1:	indiValue = Indicators.EMA(Input, Period).Value.get(0); break;
			case 2: indiValue = Indicators.SMMA(Input, Period).Value.get(0); break;
			case 3: indiValue = Indicators.LWMA(Input, Period).Value.get(0); break;
			default: throw new TradingException(String.format("Undefined MA Method: %d !", MAMethod));
		}
		
		Value.set(0, indiValue);
	}

	//------------------------------------------------------------------------

	@Override
	public double OnBlockEvaluate(int relativeShift) throws TradingException {
		return Indicators.MA(Input, Period, MAMethod).Value.get(relativeShift + Shift);
	}
}
